#
# spec file for package reiserfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           reiserfs
BuildRequires:  acl-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libcom_err-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  pkg-config
BuildRequires:  xz
# Git-url:	git://git.kernel.org/pub/scm/linux/kernel/git/jeffm/reiserfsprogs.git
Url:            https://www.kernel.org/pub/linux/kernel/people/jeffm/reiserfsprogs
Conflicts:      libreiserfs-progs
Supplements:    filesystem(reiserfs)
Version:        3.6.27
Release:        59.1
Summary:        Reiser File System utilities
License:        GPL-2.0+
Group:          System/Filesystems
Source:         reiserfsprogs-%{version}.tar.xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Patch1:         silent-rules.patch
Requires:       libreiserfscore0 = %{version}

%description
This package includes utilities for making the file system
(mkreiserfs), checking for consistency (reiserfsck), and resizing
(resize_reiserfs).

%package -n libreiserfscore-devel
Summary:        Reiser File System Core Library Development Files
Group:          Development/Libraries/C and C++
Requires:       libcom_err-devel
Requires:       libreiserfscore0 = %{version}
Requires:       libuuid-devel

%description -n libreiserfscore-devel
This package contains the headers and linkable libraries for
libreiserfscore, which is used to provide reiserfs services for external
programs.

%package -n libreiserfscore0
Summary:        Reiser File System Core Library
Group:          System/Filesystems
Conflicts:      reiserfs < %{version}

%description -n libreiserfscore0
This package contains the library that provides core functionality
for the reiserfs file system.

%prep
%setup -q -n reiserfsprogs-%{version}
%patch1 -p1

%build
autoreconf -fiv
export CFLAGS="%optflags"
%configure --exec-prefix=/ --bindir=/bin --sbindir=/sbin
make %{?_smp_mflags}

%install
install	-d	${RPM_BUILD_ROOT}/sbin
make DESTDIR=${RPM_BUILD_ROOT} install
cd ${RPM_BUILD_ROOT}/sbin

%files
%defattr(-, root, root)
/sbin/*
%doc %{_mandir}/man8/*
%doc COPYING

%files -n libreiserfscore-devel
%defattr(-, root, root)
%dir %{_includedir}/reiserfs
%{_includedir}/reiserfs/*.h
%{_libdir}/pkgconfig/reiserfscore.pc
%{_libdir}/libreiserfscore.a
%{_libdir}/libreiserfscore.la
%{_libdir}/libreiserfscore.so
%{_libdir}/libreiserfscore.so.0

%files -n libreiserfscore0
%defattr(-, root, root)
%{_libdir}/libreiserfscore.so.0.0.0

%post -n libreiserfscore0 -p /sbin/ldconfig
%postun -n libreiserfscore0 -p /sbin/ldconfig

%changelog
* Wed Nov 29 2017 jeffm@suse.com
- Added COPYING to %%doc
* Wed Nov 22 2017 jeffm@suse.com
- Add conflicts for libreiserfscore0 and earlier reiserfs package (bsc#1071088).
* Tue Jul 25 2017 jeffm@suse.com
- Update with respun 3.6.27.
* Tue Jul 25 2017 jeffm@suse.com
- Update to 3.6.27
  - build: use @PACKAGE_VERSION@ instead of @REISERFSCORE_VERSION@ in .pc file
  - xattrs: handle both hash forms in reiserfs_check_xattr
  - misc: include <sys/sysmacros.h>
- reiserfs package now depends on libreiserfscore0
* Thu Jun 22 2017 jeffm@suse.com
- Update to 3.6.26
  - Fixes a NULL pointer dereference caused by reiserfsck.
  - build: libcom_err is required
  - reiserfscore: add reiserfs_err.et to EXTRA_DIST
* Mon Jun  6 2016 jeffm@suse.com
- Update to 3.6.25
  - reiserfsprogs: use com_err in reiserfs_open
  - reiserfscore: fix "new_insert_key may be used uninitialized..."
  - reiserfsprogs: fix issues with inline functions
  - man: Fixes a little glitch in the man page.
  - manpages: escape dashes
  - fsck: remove namesys.com reference in error text
  - reiserfscore: constify struct pointer arguments
  - reiserfscore: constify strings
  - reiserfslib: add basic extended attribute helpers
  - reiserfslib: add file data and directory iterators
  - mkreiserfs: move block_size_ok out of reiserfscore
  - debugreiserfs: fix incorrect memset size in unpack_stat_data
  - reiserfsprogs: remove dead code
  - debugreiserfs: fix use after free while closing log
  - reiserfsprogs: add helpers for constant endian routines
  - Removed patch debugreiserfs-fix-use-after-free-while-closing-log
* Mon Mar 23 2015 crrodriguez@opensuse.org
- Use -fgnu89-inline, fixes build with gcc5.
* Wed Nov  6 2013 jeffm@suse.com
- debugreiserfs-fix-use-after-free-while-closing-log:
  debugreiserfs: fix use after free while closing log (bnc#849264).
* Tue Sep 17 2013 jeffm@suse.com
- Update to upstream master (57eac84)
  - reiserfsprogs: add helpers for constant endian routines
* Mon Sep 16 2013 jeffm@suse.com
- silent-rules.patch: Add workaround for missing AM_SILENT_RULES
* Mon Sep 16 2013 jeffm@suse.com
- Update to upstream master (19566d0)
  - build: introduce shared libreiserfscore.so and export it
  - reiserfsprogs: convert reiserfs_filsys_t from structure to pointer-to-structure
  - reiserfsprogs: annotate for endian safeness
  - reiserfsprogs: fix remaining sparse warnings
  - reiserfsprogs: Fix sparse "warning: Using plain integer as NULL pointer"
  - sparse: move bitops functions to include/misc.h
  - reiserfscore: rename usearch_by_position to reiserfs_search_by_position
  - reiserfscore: make reiserfs_open's filename argument const
  - swab: protect le32_to_cpu and friends against being defined twice
  - reiserfs_fs.h: Eliminate overlays in offset_v2 helpers
  - reiserfscore: move endian helpers for offset_v2 into header
  - reiserfs_fs.h: Fix ifndef for multiple inclusion
* Tue Aug 27 2013 jeffm@suse.com
- Update to 3.6.24.
  - reiserfsprogs: autogenerate the version number in the man pages
  - journal: fix division by 0 with one transaction in log (crash)
  - resize_reiserfs: fix > 8TB printf formatting
  - Packaging cleanups.
* Mon Jul  1 2013 jeffm@suse.com
- Update to 3.6.23.
  - Includes previous packaged fixes.
  - Mostly build/warning fixes.
* Thu May 24 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Aug  8 2011 jeffm@suse.de
- Fix signedness issues for large file systems
* Thu Apr 15 2010 jeffm@suse.de
- Fix use-after-free crash in reiserfsck w/ free poisoning
* Sat Jan 10 2009 jeffm@suse.de
- Update to 3.6.21
  - Includes our entire patch queue.
  - Fix for disallowing block sizes < 4k.
* Thu Mar 13 2008 jeffm@suse.com
- mkreiserfs now creates the root directory with the ownership
  of the calling user. (bnc#369006)
* Sat Jan 26 2008 jeffm@suse.com
- Added dependency on linux-kernel-headers for asm/types.h
* Thu Jan 24 2008 jeffm@suse.com
- Backported patches to 3.6.19 and backed out the 3.6.20 update. (#355584)
- Added patch to remove unfulfilled dependency on asm/unaligned.h
* Mon Jan 14 2008 jeffm@suse.com
- Build fixes for big-endian machines.
* Thu Jan  3 2008 jeffm@suse.com
- Removed several common system-defined typedefs that were wrong
  for ia64.
* Tue Dec  4 2007 jeffm@suse.com
- Updated to 3.6.20
  - Numerous fixes
  - Code refactoring into saner directories
  - Native >= 8 TB support
- Added progress/spinner
- Added fsck -a mount count and timestamping for faster booting
* Mon Aug 13 2007 jeffm@suse.com
- Fixes for file systems >= 8 TiB
* Mon Aug  6 2007 olh@suse.de
- remove inclusion of asm/unaligned.h
  use a copy of asm-generic/unaligned.h instead
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Wed Mar 28 2007 jeffm@suse.com
- Added Supplements: filesystem(reiserfs) to spec file (FATE 301966)
* Tue Feb 20 2007 jeffm@suse.com
- Added O_EXCL to reiserfs_create()'s open() call
* Tue Feb 13 2007 jeffm@suse.com
- Added progress bar and silenced journal replay messages with
  - a mode.
* Tue Feb 13 2007 jeffm@suse.com
- Removed fsck_sleep call that causes reiserfsck to stay in the
  background for 5s, causing problems with multipath and kpartx
* Thu May  4 2006 jeffm@suse.com
- Added fix for off-by-one in memory allocation of oid map. Would
  cause crash on file systems with OID 2^32-2 in use.
- Added patch to use better defaults for journals on external
  devices..
* Thu Mar  2 2006 jeffm@suse.com
- Added warning for block sizes > 4k
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 21 2005 mmj@suse.de
- This package conflicts with libreiserfs-progs
* Fri Dec  9 2005 schwab@suse.de
- Update to reiserfsprogs 3.6.19.
- Remove broken inline.
- Don't strip binaries.
* Thu Sep  1 2005 ro@suse.de
- fix build on ppc: define __KERNEL__ before including unaligned.h
* Tue Aug 17 2004 bk@suse.de
- update to 3.6.18, Jeff Mahoney checked which patches are needed
* Thu Jul 15 2004 schwab@suse.de
- Fix unaligned accesses [#40296].
* Mon Jun 21 2004 meissner@suse.de
- Fix from Jeff Mahoney to do mkfs checks without checking
  the quietness flag (SUSE#42118 / LTC#9409).
* Fri May 21 2004 mason@suse.com
- Fix from Jeff Mahoney to make --rebuild-tree properly handle
  the new block allocator in sles9 kernels
* Tue May 18 2004 meissner@suse.de
- BLKGETSIZ64 has a 32bit size ioctl encoding, but a 64bit size
  argument. (SUSE#40645, LTC#8586).
* Mon Apr  5 2004 kukuk@suse.de
- Remove duplicate patch once from filelist
* Tue Mar 16 2004 mason@suse.de
- fix mounted filesystem detection
* Thu Feb 26 2004 mantel@suse.de
- create links for manpages fsck.reiserfs and mkfs.reiserfs
* Sun Feb  8 2004 mason@suse.de
- update to 3.6.13
* Thu Nov 13 2003 schwab@suse.de
- Use count_blocks when checking block device size [#32611].
- Fix descriptor leak.
* Mon Sep  1 2003 mason@suse.de
- make -a imply -q
* Mon Aug 18 2003 arvin@suse.de
- applied 64 bit patch (bug #28424)
* Mon Jul 28 2003 mason@suse.com
- update to 3.6.9 / 3.6.10
* Thu Jun 26 2003 uli@suse.de
- fixed wrong file size limit on 64 bit machines (bug #27534)
* Mon Feb 10 2003 mason@suse.com
- update to 3.6.4
* Fri Aug  9 2002 mason@suse.de
- Add two new patches which:
  o changes reiserfsck to use more standard 'Filesystem clean'
  o fixes sd_blocks calculation to match quota code's for
    symbolic links
* Mon Jul 15 2002 mmj@suse.de
- Up to 3.6.2
- Add two new patches from Chris Mason which:
  o Changes the reiserfsck exit codes to match e2fsck
  o Drops a harmless warning message
* Tue Jun  4 2002 bk@suse.de
- add missing reiserfstune including man page to filelist
* Mon Mar 11 2002 mantel@suse.de
- update to version 3.x.1b
- make startup output at least a little bit less ugly
* Wed Feb 27 2002 mantel@suse.de
- create link mkfs.reiserfs -> mkreiserfs for consistency
* Tue Feb 12 2002 mantel@suse.de
- fix bug in objectid sorting code (only affects objectids > 2^31)
* Mon Feb 11 2002 ro@suse.de
- update to 3.x.1b-pre3
* Wed Nov 28 2001 aj@suse.de
- Update to newer version, add patch from Chris Mason to fix some
  quota bugs.
* Fri Sep 21 2001 fehr@suse.de
- add patches resizer_dirty.diff and prints-nr.diff from Chris Mason
  to package
* Thu Sep 20 2001 kukuk@suse.de
- Make default version 3.6.x on PPC, too.
* Thu Sep 13 2001 mge@suse.de
- introduced BuildRoot into the SPEC-file
- added %%clean section
- added patch5: "resize_reiserfs-bitmap.diff" by Chris Mason
  to make resize_reiserfs work
* Mon Sep 10 2001 olh@suse.de
- remove mkreiserfs-mmap-die.diff
  add mkreiserfs-bigmem.diff from jeffm
  allows to run the tools on machines with a lot of ram
* Thu Sep  6 2001 kukuk@suse.de
- Make default version 3.6.x on SPARC (3.5 does not work on
  bigendian)
* Wed Aug 29 2001 olh@suse.de
- add mkreiserfs-mmap-die.diff, score goes to jeffm
* Tue Aug 28 2001 fehr@suse.de
- add 3 patches from Chris Mason
- default version still 3.5.x.,
- exit code of debugreiserfs meaningful
- mkreiserfs understands option -q
* Sat Jul 21 2001 kukuk@suse.de
- Update to 3.x.0k-pre9 with endian-save patch from jeffm
* Wed Jun 27 2001 bk@suse.de
- update to 3.x.0k-pre8 with endian-safe pre8-patch from jeffm
- cleaned up obsolete neededforbuild
* Wed May  2 2001 schwab@suse.de
- Use proper largefile access instead of stupid hardcoded syscall.
- Fix missing declarations.
- Fix missing casts.
* Thu Apr 26 2001 mantel@suse.de
- do not return success when used on a non-reiserfs partition
* Thu Apr 26 2001 mantel@suse.de
- added link fsck.reiserfs -> reiserfsck
* Tue Apr 24 2001 mantel@suse.de
- update to reiserfsprogs-3.x.0j
* Thu Feb 22 2001 ro@suse.de
- use kernel include dir
* Sat Jan 20 2001 mantel@suse.de
- update to 3.5.29
* Fri Dec 15 2000 mantel@suse.de
- up to 3.5.28
* Wed Nov 15 2000 kukuk@suse.de
- compile against kernel 2.2.x
* Wed Oct 25 2000 mantel@suse.de
- up to 3.5.27
* Wed Aug  2 2000 mantel@suse.de
- install man page for reiserfsck
* Fri Jul 14 2000 mantel@suse.de
- added z-free_thrown.diff
* Tue Jul 11 2000 mantel@suse.de
- update to 3.5.23
* Sun Jun 18 2000 ro@suse.de
- fixed makefiles
* Sat Jun 17 2000 mantel@suse.de
- up to 3.5.22
* Fri Jun  9 2000 ro@suse.de
- up to 3.5.21
* Tue Mar 21 2000 ro@suse.de
- removed fsck.reiserfs (doesn't work)
* Thu Mar 16 2000 ro@suse.de
- fixed filelist: added reiserfsck
* Thu Mar  2 2000 ro@suse.de
- up to 3.5.18
* Mon Feb  7 2000 ro@suse.de
- update to 3.5.17pre2
* Tue Jan 25 2000 ro@suse.de
- fixed typo in makefile
* Mon Jan 10 2000 ro@suse.de
- added unpackreiserfs and dumpreiserfs to filelist
* Mon Jan 10 2000 ro@suse.de
- update to 3.5.14
* Fri Dec 10 1999 ro@suse.de
- fixed Makefile
* Thu Dec  2 1999 bs@suse.de
- fixed .changes
* Thu Dec  2 1999 bs@suse.de
- update to 3.5.12
* Tue Nov 16 1999 choeger@suse.de
- new version, 3.5.7 incl. journaling
* Wed Oct 27 1999 uli@suse.de
- new package
